==> apache-camel-quarkus-2.16.0-src.zip: camel-quarkus-2.16.0/test-framework/junit5-extension-tests/src/test/java/org/apache/camel/quarkus/test/extensions/routeBuilder/RouteBuilderWarningET.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.test.extensions.routeBuilder;

import io.quarkus.test.junit.QuarkusTest;
import io.restassured.RestAssured;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.quarkus.test.CamelQuarkusTestSupport;
import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;

@QuarkusTest
public class RouteBuilderWarningET extends CamelQuarkusTestSupport {

    @Override
    public boolean isUseRouteBuilder() {
        return true;
    }

    @Test
    public void helloTest() throws Exception {
        RestAssured.given()
                .body("Hello (from routeBuilder) ")
                .post("/routeBuilder/in")
                .then()
                .statusCode(204);

        RestAssured.given()
                .body("file:target/data/RouteBuilderET?fileName=hello_true.txt")
                .post("/hello/message")
                .then()
                .statusCode(200)
                .body(is("Hello (from routeBuilder) Sheldon"));
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:in").routeId("directRoute").to("file:target/data/RouteBuilderET?filename=hello_true.txt");
            }
        };
    }
}

==> apache-camel-quarkus-3.20.4-src.zip: camel-quarkus-3.20.4/test-framework/junit5-extension-tests/src/test/java/org/apache/camel/quarkus/test/extensions/routeBuilder/RouteBuilderWarningET.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.test.extensions.routeBuilder;

import io.quarkus.test.junit.QuarkusTest;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.quarkus.test.CamelQuarkusTestSupport;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

@QuarkusTest
public class RouteBuilderWarningET extends CamelQuarkusTestSupport {

    @Override
    public boolean isUseRouteBuilder() {
        return true;
    }

    @Test
    public void helloTest() throws Exception {
        Assertions.assertTrue(true);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:in").routeId("directRoute").to("file:target/data/RouteBuilderET?filename=hello_true.txt");
            }
        };
    }
}
